/*
This script provides as example of using the InstaCompOne compression 
and decompression tools to create a very simple script that installs 
one SimpleText file (Example File) and a family of fonts (Helvetica).

The File Atom and Font Atom reference the ID of the 'inex' resource (ID 241) 
that is included from the file "InstaCompOneAtomExt.rsrc".

*/


#include "InstallerTypes.r"

// Include the InstaCompOne atom extender stuff
// making sure not to add their version resource
// to our installer script. Also, since this include
// is a resource include instead of a #include, it is
// not actually a pre-processor thing, and won't be effected
// by a -i option within the rez line in the makefile. 
include ":::Tools:Released:InstaCompOne 1.1:InstaCompAtomExt.rsrc" NOT 'vers';

/************************** Package resources **********************************/
resource 'inpk' (20037) {
	format0 {
		showsOnCustom,
		notRemovable,
		dontForceRestart,
		0,
		0,
		"Example File Decompression",
		{
			'infa', 1001
		}
	}
};

resource 'inpk' (20038) {
	format0 {
		showsOnCustom,
		notRemovable,
		dontForceRestart,
		0,
		0,
		"Helvetica Font Decompression Example",
		{
			'inff', 1001
		}
	}
};

/************************** Example File Atom **********************************/
resource 'infa' (1001) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,
		dontIgnoreLockedFile,
		dontSetFileLocked,
		useVersProcToCompare,
		srcNeedExist,
		rsrcForkInDataFork,
		leaveAloneIfNewer,
		updateExisting,
		copyIfNewOrUpdate,
		rsrcFork,
		dataFork,
		0,					/* Total size will be filled in by ScriptCheck */
		0,					/* Finder attributes will be filled in by ScriptCheck */
		10000,
		{	20000, 0, 0 },	/* sizes will be filled in by ScriptCheck */
		0x0,
		0,
		241,
		""
	}
};

/************************** Example Helvetica Font Atom **********************************/
resource 'inff' (1001) {
	format2 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,
		encodedFONDRsrc,
		noTgtRequired,
		updateExisting,
		copyIfNewOrUpdate,
		dontIgnoreProtection,
		srcNeedExist,
		byID,
		nameNeedNotMatch,
		10002,		/* Target */
		20000,		/* Source */
		32,			/* FOND Attributes */
		0,			/* Total font size, filled in by ScriptCheck */
		21,			/* FOND ID */
		explicitFamilyMembers {{
			 0, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'sfnt', 32, { 20000, 'part', 200, 0, "" },
			 0, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, boldStyle, 	'sfnt', 32, { 20000, 'part', 201, 0, "" },
			 9, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 202, 0, "" },
			10, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 203, 0, "" },
			12, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 204, 0, "" },
			14, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 205, 0, "" },
			18, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 206, 0, "" },
			24, noExtendedStyle, noCondensedStyle, noShadowStyle, noOutlineStyle, noUnderlineStyle, noItalicStyle, noBoldStyle, 'NFNT', 32,	{ 20000, 'part', 207, 0, "" }
		}},
		241,
		"",
		"Helvetica"
	}
};

/************************** Example File Target File Spec. **********************************/
// target file spec for Example File
resource 'intf' (10000) {
	format1 {
		noSearchForFile, 				// use default search path
		
		typeCrNeedNotMatch, 			// If this is set to TypeCrMustMatch
										// then a file with a different type
										// and creator than those specified
										// below will not be replaced.
										// If this is set to TypeCrNeedNotMatch
										// then type and creator of an existing
										// target file are ignored.
		
		// The Type and Creator fields will be used to set the
		// file's Type and Creator when a new file is created. 
		'ttro', 						// TYPE for new file
		'ttxt', 						// CREATOR for new file
		
		0, 								// finder attribute flags
										// filled by ScriptCheck is value is 0
		
		1, 			 					// creation date for new file
		1, 			 					// modification date for new file
										// NOTE: DATE values are filled
										// by ScriptCheck if the value is 1
											
		0,				 				// search proc ID ( 'insp' ), none used
		
		"folder-user:Example File"		// target path to file
		}
	};

/*********************** Font Suitcase Target File Spec. *******************************/

resource 'intf' (10002) {
	format1 {
		noSearchForFile, 				// use default search path
		
		typeCrNeedNotMatch, 			// If this is set to TypeCrMustMatch
										// then a file with a different type
										// and creator than those specified
										// below will not be replaced.
										// If this is set to TypeCrNeedNotMatch
										// then type and creator of an existing
										// target file are ignored.
		
		// The Type and Creator fields will be used to set the
		// file's Type and Creator when a new file is created. 
		'FFIL', 						// TYPE for new file
		'DMOV', 						// CREATOR for new file
		
		0, 								// finder attribute flags
										// filled by ScriptCheck is value is 0
		
		1, 			 					// creation date for new file
		1, 			 					// modification date for new file
										// NOTE: DATE values are filled
										// by ScriptCheck if the value is 1
											
		0,				 				// search proc ID ( 'insp' ), none used
		
		"folder-user:Example Fonts"		// path to target file
		}
	};

/************************** Archive Source File Spec. **********************************/
resource 'infs' (20000) {
	'ircp',
	'kakc',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Tidbits:Installation Data"
};


/************************** Preference Resource **********************************/
resource 'inpr' (300) {
	format0 {
		useFolderTargetMode,
		dontAllowUserToSetSystemDisk,
		showSelectedSizeInCustom,
		noSetupFunctionSupplied,
		dontAllowCleanInstall,
		dontAllowServerAsTarget,
		0,
		0,
			{	
			301, 311, 301, 311,
			302, 312, 302, 312
			},
		"Example Folder"
		}
	};


